==> trip-0.1.0.tar.gz: trip-0.1.0/util/Common.h <==
#ifndef COMMON_H
#define COMMON_H

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */





static const char* const CommonHeaderVersion =
    "$Id: Common.h,v 1.24 2000/10/20 22:29:37 ghuang Exp $";

#include "vtypes.h"

enum TimerEventType
{
    UnknownTimer = 0,
    SyncCompleteAckTimer,
    SyncRequestTimer,
    SynchronizingTimer,
    StartupDelayTimer,
    SyncDelayTimer
};

enum ServerType
{
    Unknown = 0,
    FS,
    MS,
    RS,
    JS,
    Agent,
    NetMgnt,
    SipStack,
    CDR,
    MgcpStack,
    H323,
    UA,
    HB,
    POS,
    CA,
    PS,
    UAVM
};


enum ServerStatus
{
    Inactive = 0,
    Active,
    ActivePending,
    UnknownStatus
};


enum DataType
{
    UnknownData = 0,
    HeartbeatData,
    RedundancyData,
    MaintenanceData
};


enum InfoType
{
    NA = 0,
    SyncCompAck,
    SyncCompFail,
    SyncCompSucc,
    SyncReq,
    SyncReqAck,
    SyncReqFail,
    MaintPortChg
};


typedef struct
{
    u_int16_t dataType;
    u_int16_t padding;
    u_int16_t port;
    u_int16_t load;
}
heartbeatPortData;


typedef struct
{
    u_int16_t dataType;
    u_int16_t padding;
    u_int16_t port;
    u_int16_t info;
    u_int32_t misc;
}
redundancyPortData;


// the following may need to be at a higher level
enum voReturnStatus
{
    voSuccess,
    voSuccessWithIssues,
    voNoMoreData,
    voFailure,
    voUnknown,
    voTimeout,
    voInvalidInParm
};


// this enum is to show the redirect server state.
enum RSSTATE
{
    RSACTIVE,
    RSINACTIVE,
    RSBUSY
};


#endif //COMMON_H

==> trip-1.0.0.tar.gz: trip-1.0.0/util/Common.h <==
#ifndef COMMON_H
#define COMMON_H

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */


static const char* const CommonHeaderVersion =
    "$Id: Common.h,v 1.29 2001/02/05 21:35:31 maivu Exp $";


#include "vtypes.h"


enum ServerType
{
    Unknown = 0,
    FS,
    MS,
    RS,
    JS,
    Agent,
    NetMgnt,
    SipStack,
    CDR,
    MgcpStack,
    H323,
    UA,
    HB,
    POS,
    CA,
    PS,
    UAVM
};

enum ServerStatus
{
    Inactive = 0,
    Active,
    ActivePending,
    UnknownStatus
};


enum DataType
{
    UnknownData = 0,
    HeartbeatData,
    RedundancyData,
    MaintenanceData
};


typedef struct
{
    u_int16_t dataType;
    u_int16_t padding;
    u_int16_t port;
    u_int16_t load;
}
heartbeatPortData;


typedef struct
{
    u_int16_t dataType;
    u_int16_t padding;
    u_int16_t port;
    u_int16_t info;
    u_int32_t misc;
}
redundancyPortData;


/* the following may need to be at a higher level */
enum voReturnStatus
{
    voSuccess,
    voSuccessWithIssues,
    voNoMoreData,
    voFailure,
    voUnknown,
    voTimeout,
    voInvalidInParm
};


#endif /* COMMON_H */
